@@ -42,6 +42,12 @@ impl Iupac {
     }
 }
 
+impl std::fmt::Display for Iupac {
+    fn fmt(&self, f: &mut fmt::Formatter<'_>) -> fmt::Result {
+        write!(f, "{}", std::char::from_u32(**self as u32).unwrap())
+    }
+}
+
 #[derive(Parser)]
 #[grammar = "grammar/formula.pest"]
 pub(crate) struct FormulaParser;
@@ -213,15 +219,15 @@ impl std::fmt::Display for Formula {
             Formula::Terminal(FormulaTerminal::Atom {
                 sample,
                 vafs: VAFSpectrum::Set(vafs),
-            }) => {
-                if self.is_terminal_false() {
-                    "false".to_owned()
-                } else {
-                    vafs.iter()
-                        .map(|vaf| format!("{}:{}", sample, vaf))
-                        .join("|")
-                }
-            }
+            }) => match vafs.len() {
+                1 => format!("{}:{}", sample, vafs.iter().next().unwrap()),
+                x if x > 1 => format!(
+                    "{}:{{{}}}",
+                    sample,
+                    vafs.iter().map(|vaf| format!("{:.3}", vaf)).join(", "),
+                ),
+                _ => "false".to_owned(),
+            },
             Formula::Terminal(FormulaTerminal::Atom {
                 sample,
                 vafs: VAFSpectrum::Range(vafrange),
@@ -240,8 +246,8 @@ impl std::fmt::Display for Formula {
             }) => format!(
                 "{negate}({refbase}>{altbase})",
                 negate = if *positive { "" } else { "!" },
-                refbase = **refbase,
-                altbase = **altbase,
+                refbase = refbase,
+                altbase = altbase,
             ),
             Formula::Terminal(FormulaTerminal::Expression {
                 identifier,
@@ -977,8 +983,8 @@ impl std::fmt::Display for NormalizedFormula {
             } => format!(
                 "{negate}({refbase}>{altbase})",
                 negate = if *positive { "" } else { "!" },
-                refbase = **refbase,
-                altbase = **altbase,
+                refbase = refbase,
+                altbase = altbase,
             ),
             NormalizedFormula::Conjunction { operands } => {
                 operands.iter().map(&fmt_operand).join(" & ")
